// KEDS_count
// Version 3.0
// Rewritten in C++ April 2003 by Nicolas Frisby
// Kansas Event Data System Project
// Philip A. Schrodt
// Dept of Politial Science
// University of Kansas
// Lawrence, KS 66045
// internet:  p-schrodt@ukans.edu

// Revision History
// 1.0 Philip Schrodt in Pascal
// 2.0 Star Straf rewrite in Java
// 2.01 Added rounding to Scale and directory path to command file
// 2.02 Send output files to directory that command file is in
// 3.0 Nicolas Frisby rewrite in C++ (added leap year handling and fixed wildcard functionality)

//HEADER cKEDS Count

// INCLUDES
#include <iostream>
#include <fstream>
#include <cstddef>
#include <ctime>
#include <cmath>
#include <cstdio> 
#include <conio.h>
#include <windows.h>
using namespace std; 	//introduces namespace std

// CONSTANTS
const char* VER = "Ver 2.02 ";
const int CODEVALUEMAX = 256;
const int FILESMAX = 16;
const int COUNTMAX = 256;
const int TARGETSMAX = 16;
const char  TAB = '\t';
//NEW FOR C VERSION
const int MAX_INPUT = 128;
const int MAX_LINE  = 256;
const int MAX_VAR_LINE = 4096;

const int MAX_PREF = 20;
const int MAX_FREQ  = 20;
const int MAX_CAL = 12;
const int MAX_WEEK = 20;
const int MAX_OUTPUT = 10;

const int MAX_CODE = 5;
const int MAX_VAL = 10;

const int MAX_FILENAME = 64; //TODO: good size?
const int MAX_DIR = 128;	//TODO: good size?
const int MAX_KC_PATH = MAX_FILENAME + MAX_DIR;

const int MAX_COUNT = 5; //TODO: good size?

const int MAX_DYAD = 12; //TODO: good size?

const int MAX_DATE = 26;

const int MAX_EVENT_LINE = MAX_LINE; //TODO: too strict?: MAX_DATE + 1 + MAX_DYAD + 1 + MAX_DYAD + 1 + MAX_CODE + 2; // the 1's are for tabs and newline (whitespace)

// Command file variables divided by section
// - FORMAT  section
char 		formatPrefix[MAX_PREF];
int     	formatDate 	= 1;
int 		formatSource 	= 2;
int 		formatTarget 	= 3;
int 		formatEvent 	= 4;
char 		formatFreq[MAX_FREQ];
char 		formatCalendar[MAX_CAL];
//  SimpleDateFormat formatSDF; 
// Feedback is the count of how often to display =+*
int			formatFeedback	= 250; 
// Weekday is what day of the week to start a week at
char        formatWeek[MAX_WEEK];
// What type of file format you want
// Can generate files by DYADS or by VARIABLES
// firstOutput is true if first Variable file, false if need
//             to concatanate with prior file
char		formatOutput[MAX_OUTPUT];
bool		firstOutput     = true;

// - SCALES  <code>:[value]
char  		code[CODEVALUEMAX][MAX_CODE];
float 		value[CODEVALUEMAX];
int 		maxCodeValue    = -1;
// - FILES
char		inDir[MAX_KC_PATH] = "";
char		files[FILESMAX][MAX_FILENAME];
int 		maxFiles        = -1;
// - COUNT
char	 	countcodes[COUNTMAX][MAX_COUNT];
bool	 	wildcard[COUNTMAX];
int 		maxCount        = -1;  
// - DYADS
char	 	dSource[MAX_DYAD];
bool 		dWildcard;
bool 		tAll;
char 		dTarget[TARGETSMAX][MAX_DYAD];
bool 		dTWildcard[TARGETSMAX];
int 		maxTargets 		= -1;
ofstream*	dyadOut[COUNTMAX];  // DYADS or Variables
ifstream*	priorOut[COUNTMAX]; // Back version for Variables
// Event
char 		locDate[MAX_INPUT];
char 		locSrc[MAX_INPUT];
char 		locTar[MAX_INPUT];
char 		locEvt[MAX_INPUT];
// Actual count for current Time element (day)
int				dayCount[TARGETSMAX];
float			dayScale[TARGETSMAX];
int				dayCode[TARGETSMAX][COUNTMAX];
tm				BeginDate, EndDate, CurrDate;
bool			firstData = true;
//Display variables
int				dspcnt, dspline;
char			dspchar;
